@@ -685,7 +685,6 @@ impl PanelState for BrowserState {
                 let path = self.displayed_tree().selected_line().path.to_path_buf();
                 info!("trash {:?}", &path);
 
-                #[cfg(feature = "trash")]
                 match trash::delete(&path) {
                     Ok(()) => CmdResult::RefreshState { clear_cache: true },
                     Err(e) => {
@@ -693,11 +692,6 @@ impl PanelState for BrowserState {
                         CmdResult::DisplayError(format!("trash error: {:?}", &e))
                     }
                 }
-
-                #[cfg(not(feature = "trash"))]
-                CmdResult::DisplayError(
-                    "feature not enabled or platform does not support trash".into(),
-                )
             }
             Internal::up_tree => match self.displayed_tree().root().parent() {
                 Some(path) => internal_focus::on_path(
