@@ -2,27 +2,15 @@ use {
     super::svg,
     crate::errors::ProgramError,
     image::{
-        DynamicImage,
-        GenericImageView,
-        ImageReader,
-        imageops::FilterType,
-    },
-    std::{
-        borrow::Cow,
-        path::Path,
+        imageops::FilterType, DynamicImage, GenericImageView, ImageReader
     },
+    std::path::Path,
     termimad::{
         coolor,
         crossterm::style::Color as CrosstermColor,
     },
 };
 
-// Max dimensions of the SVG image to render. A bigger size just makes it need
-// a little more memory and takes more time to render. There's no quality gain
-// in having this bigger than your screen
-pub const MAX_SVG_BITMAP_WIDTH: u32 = 1000;
-pub const MAX_SVG_BITMAP_HEIGHT: u32 = 1000;
-
 #[allow(clippy::large_enum_variant)]
 pub enum SourceImage {
     Bitmap(DynamicImage),
@@ -57,9 +45,13 @@ impl SourceImage {
         let img = match self {
             Self::Bitmap(img) => {
                 let dim = self.dimensions();
-                max_width = max_width.min(dim.0);
-                max_height = max_height.min(dim.1);
-                img.resize(max_width, max_height, FilterType::Triangle)
+                if dim.0 <= max_width && dim.1 <= max_height {
+                    img.clone()
+                } else {
+                    max_width = max_width.min(dim.0);
+                    max_height = max_height.min(dim.1);
+                    img.resize(max_width, max_height, FilterType::Triangle)
+                }
             }
             Self::Svg(tree) => {
                 let bg_color: Option<coolor::Color> = bg_color.map(|cc| cc.into());
@@ -68,18 +60,6 @@ impl SourceImage {
         };
         Ok(img)
     }
-    pub fn optimal(&self) -> Result<Cow<'_, DynamicImage>, ProgramError> {
-        let cow = match self {
-            Self::Bitmap(img) => Cow::Borrowed(img),
-            Self::Svg(tree) => Cow::Owned(svg::render_tree(
-                tree,
-                MAX_SVG_BITMAP_WIDTH,
-                MAX_SVG_BITMAP_HEIGHT,
-                None,
-            )?),
-        };
-        Ok(cow)
-    }
 }
 
 fn f32_to_u32(v: f32) -> u32 {
